package com.sun.beans;

import java.lang.ref.WeakReference;
import java.util.WeakHashMap;
import java.lang.ref.Reference;
import java.util.Map;

public final class WeakCache<K, V>
{
    private final Map<K, Reference<V>> map;
    
    public WeakCache() {
        this.map = new WeakHashMap();
    }
    
    public V get(K k) {
        Reference<Object> reference = (Reference)this.map.get(k);
        if (reference == null) {
            return null;
        }
        Object value = reference.get();
        if (value == null) {
            this.map.remove(k);
            return value;
        }
        return value;
    }
    
    public void put(K k, V referent) {
        if (referent != null) {
            this.map.put(k, new WeakReference(referent));
        }
        else {
            this.map.remove(k);
        }
    }
    
    public void clear() {
        this.map.clear();
    }
}
